"""
Python module generated from Java source file java.util.Random

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import *
from java.util.concurrent.atomic import AtomicLong
from java.util.random import RandomGenerator
from java.util.stream import DoubleStream
from java.util.stream import IntStream
from java.util.stream import LongStream
from jdk.internal.misc import Unsafe
from jdk.internal.util.random.RandomSupport import *
from typing import Any, Callable, Iterable, Tuple


class Random(RandomGenerator, Serializable):
    """
    An instance of this class is used to generate a stream of
    pseudorandom numbers; its period is only 2<sup>48</sup>.
    The class uses a 48-bit seed, which is
    modified using a linear congruential formula. (See Donald E. Knuth,
    <cite>The Art of Computer Programming, Volume 2, Third
    edition: Seminumerical Algorithms</cite>, Section 3.2.1.)
    
    If two instances of `Random` are created with the same
    seed, and the same sequence of method calls is made for each, they
    will generate and return identical sequences of numbers. In order to
    guarantee this property, particular algorithms are specified for the
    class `Random`. Java implementations must use all the algorithms
    shown here for the class `Random`, for the sake of absolute
    portability of Java code. However, subclasses of class `Random`
    are permitted to use other algorithms, so long as they adhere to the
    general contracts for all the methods.
    
    The algorithms implemented by class `Random` use a
    `protected` utility method that on each invocation can supply
    up to 32 pseudorandomly generated bits.
    
    Many applications will find the method Math.random simpler to use.
    
    Instances of `java.util.Random` are threadsafe.
    However, the concurrent use of the same `java.util.Random`
    instance across threads may encounter contention and consequent
    poor performance. Consider instead using
    java.util.concurrent.ThreadLocalRandom in multithreaded
    designs.
    
    Instances of `java.util.Random` are not cryptographically
    secure.  Consider instead using java.security.SecureRandom to
    get a cryptographically secure pseudo-random number generator for use
    by security-sensitive applications.

    Author(s)
    - Frank Yellin

    Since
    - 1.0
    """

    def __init__(self):
        """
        Creates a new random number generator. This constructor sets
        the seed of the random number generator to a value very likely
        to be distinct from any other invocation of this constructor.
        """
        ...


    def __init__(self, seed: int):
        """
        Creates a new random number generator using a single `long` seed.
        The seed is the initial value of the internal state of the pseudorandom
        number generator which is maintained by method .next.

        Arguments
        - seed: the initial seed

        See
        - .setSeed(long)

        Unknown Tags
        - The invocation `new Random(seed)` is equivalent to:
        ````Random rnd = new Random();
        rnd.setSeed(seed);````
        """
        ...


    def setSeed(self, seed: int) -> None:
        """
        Sets the seed of this random number generator using a single
        `long` seed. The general contract of `setSeed` is
        that it alters the state of this random number generator object
        so as to be in exactly the same state as if it had just been
        created with the argument `seed` as a seed. The method
        `setSeed` is implemented by class `Random` by
        atomically updating the seed to
         ````(seed ^ 0x5DEECE66DL) & ((1L << 48) - 1)````
        and clearing the `haveNextNextGaussian` flag used by .nextGaussian.
        
        The implementation of `setSeed` by class `Random`
        happens to use only 48 bits of the given seed. In general, however,
        an overriding method may use all 64 bits of the `long`
        argument as a seed value.

        Arguments
        - seed: the initial seed
        """
        ...


    def nextBytes(self, bytes: list[int]) -> None:
        """
        Generates random bytes and places them into a user-supplied
        byte array.  The number of random bytes produced is equal to
        the length of the byte array.

        Arguments
        - bytes: the byte array to fill with random bytes

        Raises
        - NullPointerException: if the byte array is null

        Since
        - 1.1

        Unknown Tags
        - The method `nextBytes` is
        implemented by class `Random` as if by:
        ````public void nextBytes(byte[] bytes) {
          for (int i = 0; i < bytes.length; )
            for (int rnd = nextInt(), n = Math.min(bytes.length - i, 4);
                 n-- > 0; rnd >>= 8)
              bytes[i++] = (byte)rnd;`}```
        """
        ...


    def nextInt(self) -> int:
        """
        Returns the next pseudorandom, uniformly distributed `int`
        value from this random number generator's sequence. The general
        contract of `nextInt` is that one `int` value is
        pseudorandomly generated and returned. All 2<sup>32</sup> possible
        `int` values are produced with (approximately) equal probability.

        Returns
        - the next pseudorandom, uniformly distributed `int`
                value from this random number generator's sequence

        Unknown Tags
        - The method `nextInt` is
        implemented by class `Random` as if by:
        ````public int nextInt() {
          return next(32);`}```
        """
        ...


    def nextInt(self, bound: int) -> int:
        """
        Returns a pseudorandom, uniformly distributed `int` value
        between 0 (inclusive) and the specified value (exclusive), drawn from
        this random number generator's sequence.  The general contract of
        `nextInt` is that one `int` value in the specified range
        is pseudorandomly generated and returned.  All `bound` possible
        `int` values are produced with (approximately) equal
        probability.

        Arguments
        - bound: the upper bound (exclusive).  Must be positive.

        Returns
        - the next pseudorandom, uniformly distributed `int`
                value between zero (inclusive) and `bound` (exclusive)
                from this random number generator's sequence

        Raises
        - IllegalArgumentException: if bound is not positive

        Since
        - 1.2

        Unknown Tags
        - The method `nextInt(int bound)` is implemented by
        class `Random` as if by:
        ````public int nextInt(int bound) {
          if (bound <= 0)
            throw new IllegalArgumentException("bound must be positive");
        
          if ((bound & -bound) == bound)  // i.e., bound is a power of 2
            return (int)((bound * (long)next(31)) >> 31);
        
          int bits, val;
          do {
              bits = next(31);
              val = bits % bound;` while (bits - val + (bound-1) < 0);
          return val;
        }}```
        
        The hedge "approximately" is used in the foregoing description only
        because the next method is only approximately an unbiased source of
        independently chosen bits.  If it were a perfect source of randomly
        chosen bits, then the algorithm shown would choose `int`
        values from the stated range with perfect uniformity.
        
        The algorithm is slightly tricky.  It rejects values that would result
        in an uneven distribution (due to the fact that 2^31 is not divisible
        by n). The probability of a value being rejected depends on n.  The
        worst case is n=2^30+1, for which the probability of a reject is 1/2,
        and the expected number of iterations before the loop terminates is 2.
        
        The algorithm treats the case where n is a power of two specially: it
        returns the correct number of high-order bits from the underlying
        pseudo-random number generator.  In the absence of special treatment,
        the correct number of *low-order* bits would be returned.  Linear
        congruential pseudo-random number generators such as the one
        implemented by this class are known to have short periods in the
        sequence of values of their low-order bits.  Thus, this special case
        greatly increases the length of the sequence of values returned by
        successive calls to this method if n is a small power of two.
        """
        ...


    def nextLong(self) -> int:
        """
        Returns the next pseudorandom, uniformly distributed `long`
        value from this random number generator's sequence. The general
        contract of `nextLong` is that one `long` value is
        pseudorandomly generated and returned.

        Returns
        - the next pseudorandom, uniformly distributed `long`
                value from this random number generator's sequence

        Unknown Tags
        - The method `nextLong` is implemented by class `Random`
        as if by:
        ````public long nextLong() {
          return ((long)next(32) << 32) + next(32);`}```
        
        Because class `Random` uses a seed with only 48 bits,
        this algorithm will not return all possible `long` values.
        """
        ...


    def nextBoolean(self) -> bool:
        """
        Returns the next pseudorandom, uniformly distributed
        `boolean` value from this random number generator's
        sequence. The general contract of `nextBoolean` is that one
        `boolean` value is pseudorandomly generated and returned.  The
        values `True` and `False` are produced with
        (approximately) equal probability.

        Returns
        - the next pseudorandom, uniformly distributed
                `boolean` value from this random number generator's
                sequence

        Since
        - 1.2

        Unknown Tags
        - The method `nextBoolean` is implemented by class
        `Random` as if by:
        ````public boolean nextBoolean() {
          return next(1) != 0;`}```
        """
        ...


    def nextFloat(self) -> float:
        """
        Returns the next pseudorandom, uniformly distributed `float`
        value between `0.0` and `1.0` from this random
        number generator's sequence.
        
        The general contract of `nextFloat` is that one
        `float` value, chosen (approximately) uniformly from the
        range `0.0f` (inclusive) to `1.0f` (exclusive), is
        pseudorandomly generated and returned. All 2<sup>24</sup> possible
        `float` values of the form *m&nbsp;x&nbsp;*2<sup>-24</sup>,
        where *m* is a positive integer less than 2<sup>24</sup>, are
        produced with (approximately) equal probability.

        Returns
        - the next pseudorandom, uniformly distributed `float`
                value between `0.0` and `1.0` from this
                random number generator's sequence

        Unknown Tags
        - The method `nextFloat` is implemented by class
        `Random` as if by:
        ````public float nextFloat() {
          return next(24) / ((float)(1 << 24));`}```
        The hedge "approximately" is used in the foregoing description only
        because the next method is only approximately an unbiased source of
        independently chosen bits. If it were a perfect source of randomly
        chosen bits, then the algorithm shown would choose `float`
        values from the stated range with perfect uniformity.
        [In early versions of Java, the result was incorrectly calculated as:
         ``` `return next(30) / ((float)(1 << 30));````
        This might seem to be equivalent, if not better, but in fact it
        introduced a slight nonuniformity because of the bias in the rounding
        of floating-point numbers: it was slightly more likely that the
        low-order bit of the significand would be 0 than that it would be 1.]
        """
        ...


    def nextDouble(self) -> float:
        """
        Returns the next pseudorandom, uniformly distributed
        `double` value between `0.0` and
        `1.0` from this random number generator's sequence.
        
        The general contract of `nextDouble` is that one
        `double` value, chosen (approximately) uniformly from the
        range `0.0d` (inclusive) to `1.0d` (exclusive), is
        pseudorandomly generated and returned.

        Returns
        - the next pseudorandom, uniformly distributed `double`
                value between `0.0` and `1.0` from this
                random number generator's sequence

        See
        - Math.random

        Unknown Tags
        - The method `nextDouble` is implemented by class
        `Random` as if by:
        ````public double nextDouble() {
          return (((long)next(26) << 27) + next(27))
            / (double)(1L << 53);`}```
        The hedge "approximately" is used in the foregoing description only
        because the `next` method is only approximately an unbiased source
        of independently chosen bits. If it were a perfect source of randomly
        chosen bits, then the algorithm shown would choose `double` values
        from the stated range with perfect uniformity.
        [In early versions of Java, the result was incorrectly calculated as:
        ``` `return (((long)next(27) << 27) + next(27)) / (double)(1L << 54);````
        This might seem to be equivalent, if not better, but in fact it
        introduced a large nonuniformity because of the bias in the rounding of
        floating-point numbers: it was three times as likely that the low-order
        bit of the significand would be 0 than that it would be 1! This
        nonuniformity probably doesn't matter much in practice, but we strive
        for perfection.]
        """
        ...


    def nextGaussian(self) -> float:
        """
        Returns the next pseudorandom, Gaussian ("normally") distributed
        `double` value with mean `0.0` and standard
        deviation `1.0` from this random number generator's sequence.
        
        The general contract of `nextGaussian` is that one
        `double` value, chosen from (approximately) the usual
        normal distribution with mean `0.0` and standard deviation
        `1.0`, is pseudorandomly generated and returned.

        Returns
        - the next pseudorandom, Gaussian ("normally") distributed
                `double` value with mean `0.0` and
                standard deviation `1.0` from this random number
                generator's sequence

        Unknown Tags
        - The method `nextGaussian` is implemented by class
        `Random` as if by a threadsafe version of the following:
        ````private double nextNextGaussian;
        private boolean haveNextNextGaussian = False;
        
        public double nextGaussian() {
          if (haveNextNextGaussian) {
            haveNextNextGaussian = False;
            return nextNextGaussian;` else {
            double v1, v2, s;
            do {
              v1 = 2 * nextDouble() - 1;   // between -1.0 and 1.0
              v2 = 2 * nextDouble() - 1;   // between -1.0 and 1.0
              s = v1 * v1 + v2 * v2;
            } while (s >= 1 || s == 0);
            double multiplier = StrictMath.sqrt(-2 * StrictMath.log(s)/s);
            nextNextGaussian = v2 * multiplier;
            haveNextNextGaussian = True;
            return v1 * multiplier;
          }
        }}```
        
        This uses the *polar method* of G. E. P. Box, M. E. Muller, and
        G. Marsaglia, as described by Donald E. Knuth in <cite>The Art of
        Computer Programming, Volume 2, third edition: Seminumerical Algorithms</cite>,
        section 3.4.1, subsection C, algorithm P. Note that it generates two
        independent values at the cost of only one call to `StrictMath.log`
        and one call to `StrictMath.sqrt`.
        """
        ...


    def ints(self, streamSize: int) -> "IntStream":
        """
        Returns a stream producing the given `streamSize` number of
        pseudorandom `int` values.
        
        A pseudorandom `int` value is generated as if it's the result of
        calling the method .nextInt().

        Arguments
        - streamSize: the number of values to generate

        Returns
        - a stream of pseudorandom `int` values

        Raises
        - IllegalArgumentException: if `streamSize` is
                less than zero

        Since
        - 1.8
        """
        ...


    def ints(self) -> "IntStream":
        """
        Returns an effectively unlimited stream of pseudorandom `int`
        values.
        
        A pseudorandom `int` value is generated as if it's the result of
        calling the method .nextInt().

        Returns
        - a stream of pseudorandom `int` values

        Since
        - 1.8

        Unknown Tags
        - This method is implemented to be equivalent to `ints(Long.MAX_VALUE)`.
        """
        ...


    def ints(self, streamSize: int, randomNumberOrigin: int, randomNumberBound: int) -> "IntStream":
        """
        Returns a stream producing the given `streamSize` number
        of pseudorandom `int` values, each conforming to the given
        origin (inclusive) and bound (exclusive).
        
        A pseudorandom `int` value is generated as if it's the result of
        calling the following method with the origin and bound:
        ``` `int nextInt(int origin, int bound) {
          int n = bound - origin;
          if (n > 0) {
            return nextInt(n) + origin;`
          else {  // range not representable as int
            int r;
            do {
              r = nextInt();
            } while (r < origin || r >= bound);
            return r;
          }
        }}```

        Arguments
        - streamSize: the number of values to generate
        - randomNumberOrigin: the origin (inclusive) of each random value
        - randomNumberBound: the bound (exclusive) of each random value

        Returns
        - a stream of pseudorandom `int` values,
                each with the given origin (inclusive) and bound (exclusive)

        Raises
        - IllegalArgumentException: if `streamSize` is
                less than zero, or `randomNumberOrigin`
                is greater than or equal to `randomNumberBound`

        Since
        - 1.8
        """
        ...


    def ints(self, randomNumberOrigin: int, randomNumberBound: int) -> "IntStream":
        """
        Returns an effectively unlimited stream of pseudorandom `int` values, each conforming to the given origin (inclusive) and bound
        (exclusive).
        
        A pseudorandom `int` value is generated as if it's the result of
        calling the following method with the origin and bound:
        ``` `int nextInt(int origin, int bound) {
          int n = bound - origin;
          if (n > 0) {
            return nextInt(n) + origin;`
          else {  // range not representable as int
            int r;
            do {
              r = nextInt();
            } while (r < origin || r >= bound);
            return r;
          }
        }}```

        Arguments
        - randomNumberOrigin: the origin (inclusive) of each random value
        - randomNumberBound: the bound (exclusive) of each random value

        Returns
        - a stream of pseudorandom `int` values,
                each with the given origin (inclusive) and bound (exclusive)

        Raises
        - IllegalArgumentException: if `randomNumberOrigin`
                is greater than or equal to `randomNumberBound`

        Since
        - 1.8

        Unknown Tags
        - This method is implemented to be equivalent to `ints(Long.MAX_VALUE, randomNumberOrigin, randomNumberBound)`.
        """
        ...


    def longs(self, streamSize: int) -> "LongStream":
        """
        Returns a stream producing the given `streamSize` number of
        pseudorandom `long` values.
        
        A pseudorandom `long` value is generated as if it's the result
        of calling the method .nextLong().

        Arguments
        - streamSize: the number of values to generate

        Returns
        - a stream of pseudorandom `long` values

        Raises
        - IllegalArgumentException: if `streamSize` is
                less than zero

        Since
        - 1.8
        """
        ...


    def longs(self) -> "LongStream":
        """
        Returns an effectively unlimited stream of pseudorandom `long`
        values.
        
        A pseudorandom `long` value is generated as if it's the result
        of calling the method .nextLong().

        Returns
        - a stream of pseudorandom `long` values

        Since
        - 1.8

        Unknown Tags
        - This method is implemented to be equivalent to `longs(Long.MAX_VALUE)`.
        """
        ...


    def longs(self, streamSize: int, randomNumberOrigin: int, randomNumberBound: int) -> "LongStream":
        """
        Returns a stream producing the given `streamSize` number of
        pseudorandom `long`, each conforming to the given origin
        (inclusive) and bound (exclusive).
        
        A pseudorandom `long` value is generated as if it's the result
        of calling the following method with the origin and bound:
        ``` `long nextLong(long origin, long bound) {
          long r = nextLong();
          long n = bound - origin, m = n - 1;
          if ((n & m) == 0L)  // power of two
            r = (r & m) + origin;
          else if (n > 0L) {  // reject over-represented candidates
            for (long u = r >>> 1;            // ensure nonnegative
                 u + m - (r = u % n) < 0L;    // rejection check
                 u = nextLong() >>> 1) // retry
                ;
            r += origin;`
          else {              // range not representable as long
            while (r < origin || r >= bound)
              r = nextLong();
          }
          return r;
        }}```

        Arguments
        - streamSize: the number of values to generate
        - randomNumberOrigin: the origin (inclusive) of each random value
        - randomNumberBound: the bound (exclusive) of each random value

        Returns
        - a stream of pseudorandom `long` values,
                each with the given origin (inclusive) and bound (exclusive)

        Raises
        - IllegalArgumentException: if `streamSize` is
                less than zero, or `randomNumberOrigin`
                is greater than or equal to `randomNumberBound`

        Since
        - 1.8
        """
        ...


    def longs(self, randomNumberOrigin: int, randomNumberBound: int) -> "LongStream":
        """
        Returns an effectively unlimited stream of pseudorandom `long` values, each conforming to the given origin (inclusive) and bound
        (exclusive).
        
        A pseudorandom `long` value is generated as if it's the result
        of calling the following method with the origin and bound:
        ``` `long nextLong(long origin, long bound) {
          long r = nextLong();
          long n = bound - origin, m = n - 1;
          if ((n & m) == 0L)  // power of two
            r = (r & m) + origin;
          else if (n > 0L) {  // reject over-represented candidates
            for (long u = r >>> 1;            // ensure nonnegative
                 u + m - (r = u % n) < 0L;    // rejection check
                 u = nextLong() >>> 1) // retry
                ;
            r += origin;`
          else {              // range not representable as long
            while (r < origin || r >= bound)
              r = nextLong();
          }
          return r;
        }}```

        Arguments
        - randomNumberOrigin: the origin (inclusive) of each random value
        - randomNumberBound: the bound (exclusive) of each random value

        Returns
        - a stream of pseudorandom `long` values,
                each with the given origin (inclusive) and bound (exclusive)

        Raises
        - IllegalArgumentException: if `randomNumberOrigin`
                is greater than or equal to `randomNumberBound`

        Since
        - 1.8

        Unknown Tags
        - This method is implemented to be equivalent to `longs(Long.MAX_VALUE, randomNumberOrigin, randomNumberBound)`.
        """
        ...


    def doubles(self, streamSize: int) -> "DoubleStream":
        """
        Returns a stream producing the given `streamSize` number of
        pseudorandom `double` values, each between zero
        (inclusive) and one (exclusive).
        
        A pseudorandom `double` value is generated as if it's the result
        of calling the method .nextDouble().

        Arguments
        - streamSize: the number of values to generate

        Returns
        - a stream of `double` values

        Raises
        - IllegalArgumentException: if `streamSize` is
                less than zero

        Since
        - 1.8
        """
        ...


    def doubles(self) -> "DoubleStream":
        """
        Returns an effectively unlimited stream of pseudorandom `double` values, each between zero (inclusive) and one
        (exclusive).
        
        A pseudorandom `double` value is generated as if it's the result
        of calling the method .nextDouble().

        Returns
        - a stream of pseudorandom `double` values

        Since
        - 1.8

        Unknown Tags
        - This method is implemented to be equivalent to `doubles(Long.MAX_VALUE)`.
        """
        ...


    def doubles(self, streamSize: int, randomNumberOrigin: float, randomNumberBound: float) -> "DoubleStream":
        """
        Returns a stream producing the given `streamSize` number of
        pseudorandom `double` values, each conforming to the given origin
        (inclusive) and bound (exclusive).
        
        A pseudorandom `double` value is generated as if it's the result
        of calling the following method with the origin and bound:
        ``` `double nextDouble(double origin, double bound) {
          double r = nextDouble();
          r = r * (bound - origin) + origin;
          if (r >= bound) // correct for rounding
            r = Math.nextDown(bound);
          return r;`}```

        Arguments
        - streamSize: the number of values to generate
        - randomNumberOrigin: the origin (inclusive) of each random value
        - randomNumberBound: the bound (exclusive) of each random value

        Returns
        - a stream of pseudorandom `double` values,
                each with the given origin (inclusive) and bound (exclusive)

        Raises
        - IllegalArgumentException: if `streamSize` is less than zero,
                or `randomNumberOrigin` is not finite,
                or `randomNumberBound` is not finite, or `randomNumberOrigin`
                is greater than or equal to `randomNumberBound`

        Since
        - 1.8
        """
        ...


    def doubles(self, randomNumberOrigin: float, randomNumberBound: float) -> "DoubleStream":
        """
        Returns an effectively unlimited stream of pseudorandom `double` values, each conforming to the given origin (inclusive) and bound
        (exclusive).
        
        A pseudorandom `double` value is generated as if it's the result
        of calling the following method with the origin and bound:
        ``` `double nextDouble(double origin, double bound) {
          double r = nextDouble();
          r = r * (bound - origin) + origin;
          if (r >= bound) // correct for rounding
            r = Math.nextDown(bound);
          return r;`}```

        Arguments
        - randomNumberOrigin: the origin (inclusive) of each random value
        - randomNumberBound: the bound (exclusive) of each random value

        Returns
        - a stream of pseudorandom `double` values,
                each with the given origin (inclusive) and bound (exclusive)

        Raises
        - IllegalArgumentException: if `randomNumberOrigin`
                is greater than or equal to `randomNumberBound`

        Since
        - 1.8

        Unknown Tags
        - This method is implemented to be equivalent to `doubles(Long.MAX_VALUE, randomNumberOrigin, randomNumberBound)`.
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.ImmutableValueGraph

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Function
from com.google.common.collect import ImmutableMap
from com.google.common.collect import Maps
from com.google.common.graph import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import Immutable
from typing import Any, Callable, Iterable, Tuple


class ImmutableValueGraph(StandardValueGraph):
    """
    A ValueGraph whose elements and structural relationships will never change. Instances of
    this class may be obtained with .copyOf(ValueGraph).
    
    See the Guava User's Guide's <a
    href="https://github.com/google/guava/wiki/GraphsExplained#immutable-implementations">discussion
    of the `Immutable*` types</a> for more information on the properties and guarantees
    provided by this class.
    
    Type `<N>`: Node parameter type
    
    Type `<V>`: Value parameter type

    Author(s)
    - Jens Nyman

    Since
    - 20.0
    """

    @staticmethod
    def copyOf(graph: "ValueGraph"["N", "V"]) -> "ImmutableValueGraph"["N", "V"]:
        """
        Returns an immutable copy of `graph`.
        """
        ...


    @staticmethod
    def copyOf(graph: "ImmutableValueGraph"["N", "V"]) -> "ImmutableValueGraph"["N", "V"]:
        """
        Simply returns its argument.

        Deprecated
        - no need to use this
        """
        ...


    def incidentEdgeOrder(self) -> "ElementOrder"["N"]:
        ...


    def asGraph(self) -> "ImmutableGraph"["N"]:
        ...


    class Builder:
        """
        A builder for creating ImmutableValueGraph instances, especially `static final`
        graphs. Example:
        
        ````static final ImmutableValueGraph<City, Distance> CITY_ROAD_DISTANCE_GRAPH =
            ValueGraphBuilder.undirected()
                .<City, Distance>immutable()
                .putEdgeValue(PARIS, BERLIN, kilometers(1060))
                .putEdgeValue(PARIS, BRUSSELS, kilometers(317))
                .putEdgeValue(BERLIN, BRUSSELS, kilometers(764))
                .addNode(REYKJAVIK)
                .build();````
        
        Builder instances can be reused; it is safe to call .build multiple times to build
        multiple graphs in series. Each new graph contains all the elements of the ones created before
        it.

        Since
        - 28.0
        """

        def addNode(self, node: "N") -> "ImmutableValueGraph.Builder"["N", "V"]:
            """
            Adds `node` if it is not already present.
            
            **Nodes must be unique**, just as `Map` keys must be. They must also be non-null.

            Returns
            - this `Builder` object
            """
            ...


        def putEdgeValue(self, nodeU: "N", nodeV: "N", value: "V") -> "ImmutableValueGraph.Builder"["N", "V"]:
            """
            Adds an edge connecting `nodeU` to `nodeV` if one is not already present, and
            sets a value for that edge to `value` (overwriting the existing value, if any).
            
            If the graph is directed, the resultant edge will be directed; otherwise, it will be
            undirected.
            
            Values do not have to be unique. However, values must be non-null.
            
            If `nodeU` and `nodeV` are not already present in this graph, this method will
            silently .addNode(Object) add `nodeU` and `nodeV` to the graph.

            Returns
            - this `Builder` object

            Raises
            - IllegalArgumentException: if the introduction of the edge would violate .allowsSelfLoops()
            """
            ...


        def putEdgeValue(self, endpoints: "EndpointPair"["N"], value: "V") -> "ImmutableValueGraph.Builder"["N", "V"]:
            """
            Adds an edge connecting `endpoints` if one is not already present, and sets a value for
            that edge to `value` (overwriting the existing value, if any).
            
            If the graph is directed, the resultant edge will be directed; otherwise, it will be
            undirected.
            
            If this graph is directed, `endpoints` must be ordered.
            
            Values do not have to be unique. However, values must be non-null.
            
            If either or both endpoints are not already present in this graph, this method will
            silently .addNode(Object) add each missing endpoint to the graph.

            Returns
            - this `Builder` object

            Raises
            - IllegalArgumentException: if the introduction of the edge would violate .allowsSelfLoops()
            - IllegalArgumentException: if the endpoints are unordered and the graph is directed
            """
            ...


        def build(self) -> "ImmutableValueGraph"["N", "V"]:
            """
            Returns a newly-created `ImmutableValueGraph` based on the contents of this `Builder`.
            """
            ...



"""
Python module generated from Java source file org.bukkit.command.RemoteConsoleCommandSender

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.net import SocketAddress
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class RemoteConsoleCommandSender(CommandSender):

    def getAddress(self) -> "SocketAddress":
        """
        Gets the socket address of this remote sender.

        Returns
        - the remote sender's address
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.LongAdder

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.hash import *
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.io import Serializable
from java.util.concurrent.atomic import AtomicLong
from typing import Any, Callable, Iterable, Tuple


class LongAdder(Striped64, Serializable, LongAddable):
    """
    One or more variables that together maintain an initially zero `long` sum. When updates
    (method .add) are contended across threads, the set of variables may grow dynamically to
    reduce contention. Method .sum (or, equivalently, .longValue) returns the current
    total combined across the variables maintaining the sum.
    
    This class is usually preferable to AtomicLong when multiple threads update a common
    sum that is used for purposes such as collecting statistics, not for fine-grained synchronization
    control. Under low update contention, the two classes have similar characteristics. But under
    high contention, expected throughput of this class is significantly higher, at the expense of
    higher space consumption.
    
    This class extends Number, but does *not* define methods such as `equals`, `hashCode` and `compareTo` because instances are expected to be mutated, and
    so are not useful as collection keys.
    
    *jsr166e note: This class is targeted to be placed in java.util.concurrent.atomic.*

    Author(s)
    - Doug Lea

    Since
    - 1.8
    """

    def __init__(self):
        """
        Creates a new adder with initial sum of zero.
        """
        ...


    def add(self, x: int) -> None:
        """
        Adds the given value.

        Arguments
        - x: the value to add
        """
        ...


    def increment(self) -> None:
        """
        Equivalent to `add(1)`.
        """
        ...


    def decrement(self) -> None:
        """
        Equivalent to `add(-1)`.
        """
        ...


    def sum(self) -> int:
        """
        Returns the current sum. The returned value is *NOT* an atomic snapshot; invocation in
        the absence of concurrent updates returns an accurate result, but concurrent updates that occur
        while the sum is being calculated might not be incorporated.

        Returns
        - the sum
        """
        ...


    def reset(self) -> None:
        """
        Resets variables maintaining the sum to zero. This method may be a useful alternative to
        creating a new adder, but is only effective if there are no concurrent updates. Because this
        method is intrinsically racy, it should only be used when it is known that no threads are
        concurrently updating.
        """
        ...


    def sumThenReset(self) -> int:
        """
        Equivalent in effect to .sum followed by .reset. This method may apply for
        example during quiescent points between multithreaded computations. If there are updates
        concurrent with this method, the returned value is *not* guaranteed to be the final
        value occurring before the reset.

        Returns
        - the sum
        """
        ...


    def toString(self) -> str:
        """
        Returns the String representation of the .sum.

        Returns
        - the String representation of the .sum
        """
        ...


    def longValue(self) -> int:
        """
        Equivalent to .sum.

        Returns
        - the sum
        """
        ...


    def intValue(self) -> int:
        """
        Returns the .sum as an `int` after a narrowing primitive conversion.
        """
        ...


    def floatValue(self) -> float:
        """
        Returns the .sum as a `float` after a widening primitive conversion.
        """
        ...


    def doubleValue(self) -> float:
        """
        Returns the .sum as a `double` after a widening primitive conversion.
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.locks.AbstractOwnableSynchronizer

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent.locks import *
from typing import Any, Callable, Iterable, Tuple


class AbstractOwnableSynchronizer(Serializable):
    """
    A synchronizer that may be exclusively owned by a thread.  This
    class provides a basis for creating locks and related synchronizers
    that may entail a notion of ownership.  The
    `AbstractOwnableSynchronizer` class itself does not manage or
    use this information. However, subclasses and tools may use
    appropriately maintained values to help control and monitor access
    and provide diagnostics.

    Author(s)
    - Doug Lea

    Since
    - 1.6
    """





"""
Python module generated from Java source file com.google.common.util.concurrent.UncheckedExecutionException

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.util.concurrent import *
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class UncheckedExecutionException(RuntimeException):
    """
    Unchecked variant of java.util.concurrent.ExecutionException. As with `ExecutionException`, the exception's .getCause() cause comes from a failed task,
    possibly run in another thread.
    
    `UncheckedExecutionException` is intended as an alternative to `ExecutionException` when the exception thrown by a task is an unchecked exception. However, it
    may also wrap a checked exception in some cases.
    
    When wrapping an `Error` from another thread, prefer ExecutionError. When
    wrapping a checked exception, prefer `ExecutionException`.

    Author(s)
    - Charles Fry

    Since
    - 10.0
    """

    def __init__(self, message: str, cause: "Throwable"):
        """
        Creates a new instance with the given detail message and cause. Prefer to provide a
        non-nullable `cause`, as many users expect to find one.
        """
        ...


    def __init__(self, cause: "Throwable"):
        """
        Creates a new instance with `null` as its detail message and the given cause. Prefer to
        provide a non-nullable `cause`, as many users expect to find one.
        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.Breedable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Breedable(Ageable):
    """
    Represents an entity that can age and breed.
    """

    def setAgeLock(self, lock: bool) -> None:
        """
        Lock the age of the animal, setting this will prevent the animal from
        maturing or getting ready for mating.

        Arguments
        - lock: new lock
        """
        ...


    def getAgeLock(self) -> bool:
        """
        Gets the current agelock.

        Returns
        - the current agelock
        """
        ...


    def canBreed(self) -> bool:
        """
        Return the ability to breed of the animal.

        Returns
        - the ability to breed of the animal
        """
        ...


    def setBreed(self, breed: bool) -> None:
        """
        Set breedability of the animal, if the animal is a baby and set to
        breed it will instantly grow up.

        Arguments
        - breed: breedability of the animal
        """
        ...



"""
Python module generated from Java source file com.google.common.html.HtmlEscapers

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.escape import Escaper
from com.google.common.escape import Escapers
from com.google.common.html import *
from typing import Any, Callable, Iterable, Tuple


class HtmlEscapers:
    """
    `Escaper` instances suitable for strings to be included in HTML attribute values and
    *most* elements' text contents. When possible, avoid manual escaping by using templating
    systems and high-level APIs that provide autoescaping.
    One Google-authored templating system available for external use is <a
    href="https://developers.google.com/closure/templates/">Closure Templates</a>.
    
    HTML escaping is particularly tricky: For example, <a
    href="https://www.w3.org/TR/html4/types.html#h-6.2">some elements' text contents must not be HTML
    escaped</a>. As a result, it is impossible to escape an HTML document correctly without
    domain-specific knowledge beyond what `HtmlEscapers` provides. We strongly encourage the
    use of HTML templating systems.

    Author(s)
    - David Beaumont

    Since
    - 15.0
    """

    @staticmethod
    def htmlEscaper() -> "Escaper":
        """
        Returns an Escaper instance that escapes HTML metacharacters as specified by <a
        href="http://www.w3.org/TR/html4/">HTML 4.01</a>. The resulting strings can be used both in
        attribute values and in *most* elements' text contents, provided that the HTML
        document's character encoding can encode any non-ASCII code points in the input (as UTF-8 and
        other Unicode encodings can).
        
        **Note:** This escaper only performs minimal escaping to make content structurally
        compatible with HTML. Specifically, it does not perform entity replacement (symbolic or
        numeric), so it does not replace non-ASCII code points with character references. This escaper
        escapes only the following five ASCII characters: `'"&<>`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityCombustByEntityEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityCombustByEntityEvent(EntityCombustEvent):
    """
    Called when an entity causes another entity to combust.
    """

    def __init__(self, combuster: "Entity", combustee: "Entity", duration: int):
        ...


    def __init__(self, combuster: "Entity", combustee: "Entity", duration: float):
        ...


    def getCombuster(self) -> "Entity":
        """
        Get the entity that caused the combustion event.

        Returns
        - the Entity that set the combustee alight.
        """
        ...



"""
Python module generated from Java source file java.security.AccessController

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.ref import Reference
from java.security import *
from jdk.internal.reflect import CallerSensitive
from jdk.internal.reflect import Reflection
from jdk.internal.vm.annotation import DontInline
from jdk.internal.vm.annotation import ForceInline
from jdk.internal.vm.annotation import Hidden
from jdk.internal.vm.annotation import ReservedStackAccess
from sun.security.util import Debug
from sun.security.util import SecurityConstants
from typing import Any, Callable, Iterable, Tuple


class AccessController:

    @staticmethod
    def doPrivileged(action: "PrivilegedAction"["T"]) -> "T":
        ...


    @staticmethod
    def doPrivilegedWithCombiner(action: "PrivilegedAction"["T"]) -> "T":
        """
        Performs the specified `PrivilegedAction` with privileges
        enabled. The action is performed with *all* of the permissions
        possessed by the caller's protection domain.
        
         If the action's `run` method throws an (unchecked)
        exception, it will propagate through this method.
        
         This method preserves the current AccessControlContext's
        DomainCombiner (which may be null) while the action is performed.
        
        Type `<T>`: the type of the value returned by the PrivilegedAction's
                         `run` method.

        Arguments
        - action: the action to be performed.

        Returns
        - the value returned by the action's `run` method.

        Raises
        - NullPointerException: if the action is `null`

        See
        - java.security.DomainCombiner

        Since
        - 1.6
        """
        ...


    @staticmethod
    def doPrivileged(action: "PrivilegedAction"["T"], context: "AccessControlContext") -> "T":
        """
        Performs the specified `PrivilegedAction` with privileges
        enabled and restricted by the specified `AccessControlContext`.
        The action is performed with the intersection of the permissions
        possessed by the caller's protection domain, and those possessed
        by the domains represented by the specified `AccessControlContext`.
        
        If the action's `run` method throws an (unchecked) exception,
        it will propagate through this method.
        
        If a security manager is installed and the specified
        `AccessControlContext` was not created by system code and the
        caller's `ProtectionDomain` has not been granted the
        "createAccessControlContext"
        java.security.SecurityPermission, then the action is performed
        with no permissions.
        
        Type `<T>`: the type of the value returned by the PrivilegedAction's
                         `run` method.

        Arguments
        - action: the action to be performed.
        - context: an *access control context*
                       representing the restriction to be applied to the
                       caller's domain's privileges before performing
                       the specified action.  If the context is
                       `null`, then no additional restriction is applied.

        Returns
        - the value returned by the action's `run` method.

        Raises
        - NullPointerException: if the action is `null`

        See
        - .doPrivileged(PrivilegedExceptionAction,AccessControlContext)
        """
        ...


    @staticmethod
    def doPrivileged(action: "PrivilegedAction"["T"], context: "AccessControlContext", *perms: Tuple["Permission", ...]) -> "T":
        """
        Performs the specified `PrivilegedAction` with privileges
        enabled and restricted by the specified
        `AccessControlContext` and with a privilege scope limited
        by specified `Permission` arguments.
        
        The action is performed with the intersection of the permissions
        possessed by the caller's protection domain, and those possessed
        by the domains represented by the specified
        `AccessControlContext`.
        
        If the action's `run` method throws an (unchecked) exception,
        it will propagate through this method.
        
        If a security manager is installed and the specified
        `AccessControlContext` was not created by system code and the
        caller's `ProtectionDomain` has not been granted the
        "createAccessControlContext"
        java.security.SecurityPermission, then the action is performed
        with no permissions.
        
        Type `<T>`: the type of the value returned by the PrivilegedAction's
                         `run` method.

        Arguments
        - action: the action to be performed.
        - context: an *access control context*
                       representing the restriction to be applied to the
                       caller's domain's privileges before performing
                       the specified action.  If the context is
                       `null`,
                       then no additional restriction is applied.
        - perms: the `Permission` arguments which limit the
                     scope of the caller's privileges. The number of arguments
                     is variable.

        Returns
        - the value returned by the action's `run` method.

        Raises
        - NullPointerException: if action or perms or any element of
                perms is `null`

        See
        - .doPrivileged(PrivilegedExceptionAction,AccessControlContext)

        Since
        - 1.8
        """
        ...


    @staticmethod
    def doPrivilegedWithCombiner(action: "PrivilegedAction"["T"], context: "AccessControlContext", *perms: Tuple["Permission", ...]) -> "T":
        """
        Performs the specified `PrivilegedAction` with privileges
        enabled and restricted by the specified
        `AccessControlContext` and with a privilege scope limited
        by specified `Permission` arguments.
        
        The action is performed with the intersection of the permissions
        possessed by the caller's protection domain, and those possessed
        by the domains represented by the specified
        `AccessControlContext`.
        
        If the action's `run` method throws an (unchecked) exception,
        it will propagate through this method.
        
         This method preserves the current AccessControlContext's
        DomainCombiner (which may be null) while the action is performed.
        
        If a security manager is installed and the specified
        `AccessControlContext` was not created by system code and the
        caller's `ProtectionDomain` has not been granted the
        "createAccessControlContext"
        java.security.SecurityPermission, then the action is performed
        with no permissions.
        
        Type `<T>`: the type of the value returned by the PrivilegedAction's
                         `run` method.

        Arguments
        - action: the action to be performed.
        - context: an *access control context*
                       representing the restriction to be applied to the
                       caller's domain's privileges before performing
                       the specified action.  If the context is
                       `null`,
                       then no additional restriction is applied.
        - perms: the `Permission` arguments which limit the
                     scope of the caller's privileges. The number of arguments
                     is variable.

        Returns
        - the value returned by the action's `run` method.

        Raises
        - NullPointerException: if action or perms or any element of
                perms is `null`

        See
        - java.security.DomainCombiner

        Since
        - 1.8
        """
        ...


    @staticmethod
    def doPrivileged(action: "PrivilegedExceptionAction"["T"]) -> "T":
        """
        Performs the specified `PrivilegedExceptionAction` with
        privileges enabled.  The action is performed with *all* of the
        permissions possessed by the caller's protection domain.
        
         If the action's `run` method throws an *unchecked*
        exception, it will propagate through this method.
        
         Note that any DomainCombiner associated with the current
        AccessControlContext will be ignored while the action is performed.
        
        Type `<T>`: the type of the value returned by the
                         PrivilegedExceptionAction's `run` method.

        Arguments
        - action: the action to be performed

        Returns
        - the value returned by the action's `run` method

        Raises
        - PrivilegedActionException: if the specified action's
                `run` method threw a *checked* exception
        - NullPointerException: if the action is `null`

        See
        - java.security.DomainCombiner
        """
        ...


    @staticmethod
    def doPrivilegedWithCombiner(action: "PrivilegedExceptionAction"["T"]) -> "T":
        """
        Performs the specified `PrivilegedExceptionAction` with
        privileges enabled.  The action is performed with *all* of the
        permissions possessed by the caller's protection domain.
        
         If the action's `run` method throws an *unchecked*
        exception, it will propagate through this method.
        
         This method preserves the current AccessControlContext's
        DomainCombiner (which may be null) while the action is performed.
        
        Type `<T>`: the type of the value returned by the
                         PrivilegedExceptionAction's `run` method.

        Arguments
        - action: the action to be performed.

        Returns
        - the value returned by the action's `run` method

        Raises
        - PrivilegedActionException: if the specified action's
                `run` method threw a *checked* exception
        - NullPointerException: if the action is `null`

        See
        - java.security.DomainCombiner

        Since
        - 1.6
        """
        ...


    @staticmethod
    def doPrivileged(action: "PrivilegedExceptionAction"["T"], context: "AccessControlContext") -> "T":
        """
        Performs the specified `PrivilegedExceptionAction` with
        privileges enabled and restricted by the specified
        `AccessControlContext`.  The action is performed with the
        intersection of the permissions possessed by the caller's
        protection domain, and those possessed by the domains represented by the
        specified `AccessControlContext`.
        
        If the action's `run` method throws an *unchecked*
        exception, it will propagate through this method.
        
        If a security manager is installed and the specified
        `AccessControlContext` was not created by system code and the
        caller's `ProtectionDomain` has not been granted the
        "createAccessControlContext"
        java.security.SecurityPermission, then the action is performed
        with no permissions.
        
        Type `<T>`: the type of the value returned by the
                         PrivilegedExceptionAction's `run` method.

        Arguments
        - action: the action to be performed
        - context: an *access control context*
                       representing the restriction to be applied to the
                       caller's domain's privileges before performing
                       the specified action.  If the context is
                       `null`, then no additional restriction is applied.

        Returns
        - the value returned by the action's `run` method

        Raises
        - PrivilegedActionException: if the specified action's
                `run` method threw a *checked* exception
        - NullPointerException: if the action is `null`

        See
        - .doPrivileged(PrivilegedAction,AccessControlContext)
        """
        ...


    @staticmethod
    def doPrivileged(action: "PrivilegedExceptionAction"["T"], context: "AccessControlContext", *perms: Tuple["Permission", ...]) -> "T":
        """
        Performs the specified `PrivilegedExceptionAction` with
        privileges enabled and restricted by the specified
        `AccessControlContext` and with a privilege scope limited by
        specified `Permission` arguments.
        
        The action is performed with the intersection of the permissions
        possessed by the caller's protection domain, and those possessed
        by the domains represented by the specified
        `AccessControlContext`.
        
        If the action's `run` method throws an (unchecked) exception,
        it will propagate through this method.
        
        If a security manager is installed and the specified
        `AccessControlContext` was not created by system code and the
        caller's `ProtectionDomain` has not been granted the
        "createAccessControlContext"
        java.security.SecurityPermission, then the action is performed
        with no permissions.
        
        Type `<T>`: the type of the value returned by the
                         PrivilegedExceptionAction's `run` method.

        Arguments
        - action: the action to be performed.
        - context: an *access control context*
                       representing the restriction to be applied to the
                       caller's domain's privileges before performing
                       the specified action.  If the context is
                       `null`,
                       then no additional restriction is applied.
        - perms: the `Permission` arguments which limit the
                     scope of the caller's privileges. The number of arguments
                     is variable.

        Returns
        - the value returned by the action's `run` method.

        Raises
        - PrivilegedActionException: if the specified action's
                `run` method threw a *checked* exception
        - NullPointerException: if action or perms or any element of
                perms is `null`

        See
        - .doPrivileged(PrivilegedAction,AccessControlContext)

        Since
        - 1.8
        """
        ...


    @staticmethod
    def doPrivilegedWithCombiner(action: "PrivilegedExceptionAction"["T"], context: "AccessControlContext", *perms: Tuple["Permission", ...]) -> "T":
        """
        Performs the specified `PrivilegedExceptionAction` with
        privileges enabled and restricted by the specified
        `AccessControlContext` and with a privilege scope limited by
        specified `Permission` arguments.
        
        The action is performed with the intersection of the permissions
        possessed by the caller's protection domain, and those possessed
        by the domains represented by the specified
        `AccessControlContext`.
        
        If the action's `run` method throws an (unchecked) exception,
        it will propagate through this method.
        
         This method preserves the current AccessControlContext's
        DomainCombiner (which may be null) while the action is performed.
        
        If a security manager is installed and the specified
        `AccessControlContext` was not created by system code and the
        caller's `ProtectionDomain` has not been granted the
        "createAccessControlContext"
        java.security.SecurityPermission, then the action is performed
        with no permissions.
        
        Type `<T>`: the type of the value returned by the
                         PrivilegedExceptionAction's `run` method.

        Arguments
        - action: the action to be performed.
        - context: an *access control context*
                       representing the restriction to be applied to the
                       caller's domain's privileges before performing
                       the specified action.  If the context is
                       `null`,
                       then no additional restriction is applied.
        - perms: the `Permission` arguments which limit the
                     scope of the caller's privileges. The number of arguments
                     is variable.

        Returns
        - the value returned by the action's `run` method.

        Raises
        - PrivilegedActionException: if the specified action's
                `run` method threw a *checked* exception
        - NullPointerException: if action or perms or any element of
                perms is `null`

        See
        - java.security.DomainCombiner

        Since
        - 1.8
        """
        ...


    @staticmethod
    def getContext() -> "AccessControlContext":
        ...


    @staticmethod
    def checkPermission(perm: "Permission") -> None:
        ...



"""
Python module generated from Java source file com.google.gson.internal.$Gson$Types

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import *
from java.io import Serializable
from java.lang.reflect import Array
from java.lang.reflect import GenericArrayType
from java.lang.reflect import GenericDeclaration
from java.lang.reflect import Modifier
from java.lang.reflect import ParameterizedType
from java.lang.reflect import Type
from java.lang.reflect import TypeVariable
from java.lang.reflect import WildcardType
from java.util import Arrays
from java.util import NoSuchElementException
from java.util import Objects
from java.util import Properties
from typing import Any, Callable, Iterable, Tuple


class $Gson$Types:
    """
    Static methods for working with types.

    Author(s)
    - Jesse Wilson
    """

    @staticmethod
    def newParameterizedTypeWithOwner(ownerType: "Type", rawType: "Type", *typeArguments: Tuple["Type", ...]) -> "ParameterizedType":
        """
        Returns a new parameterized type, applying `typeArguments` to `rawType` and
        enclosed by `ownerType`.

        Returns
        - a java.io.Serializable serializable parameterized type.
        """
        ...


    @staticmethod
    def arrayOf(componentType: "Type") -> "GenericArrayType":
        """
        Returns an array type whose elements are all instances of `componentType`.

        Returns
        - a java.io.Serializable serializable generic array type.
        """
        ...


    @staticmethod
    def subtypeOf(bound: "Type") -> "WildcardType":
        """
        Returns a type that represents an unknown type that extends `bound`. For example, if
        `bound` is `CharSequence.class`, this returns `? extends CharSequence`. If
        `bound` is `Object.class`, this returns `?`, which is shorthand for `?
        extends Object`.
        """
        ...


    @staticmethod
    def supertypeOf(bound: "Type") -> "WildcardType":
        """
        Returns a type that represents an unknown supertype of `bound`. For example, if `bound` is `String.class`, this returns `? super String`.
        """
        ...


    @staticmethod
    def canonicalize(type: "Type") -> "Type":
        """
        Returns a type that is functionally equal but not necessarily equal according to Object.equals(Object) Object.equals(). The returned type is java.io.Serializable.
        """
        ...


    @staticmethod
    def getRawType(type: "Type") -> type[Any]:
        ...


    @staticmethod
    def equals(a: "Type", b: "Type") -> bool:
        """
        Returns True if `a` and `b` are equal.
        """
        ...


    @staticmethod
    def typeToString(type: "Type") -> str:
        ...


    @staticmethod
    def getArrayComponentType(array: "Type") -> "Type":
        """
        Returns the component type of this array type.

        Raises
        - ClassCastException: if this type is not an array.
        """
        ...


    @staticmethod
    def getCollectionElementType(context: "Type", contextRawType: type[Any]) -> "Type":
        """
        Returns the element type of this collection type.

        Raises
        - IllegalArgumentException: if this type is not a collection.
        """
        ...


    @staticmethod
    def getMapKeyAndValueTypes(context: "Type", contextRawType: type[Any]) -> list["Type"]:
        """
        Returns a two element array containing this map's key and value types in positions 0 and 1
        respectively.
        """
        ...


    @staticmethod
    def resolve(context: "Type", contextRawType: type[Any], toResolve: "Type") -> "Type":
        ...


    @staticmethod
    def requiresOwnerType(rawType: "Type") -> bool:
        """
        Whether an ParameterizedType.getOwnerType() owner type must be specified when
        constructing a ParameterizedType for `rawType`.
        
        Note that this method might not require an owner type for all cases where Java reflection
        would create parameterized types with owner type.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityRegainHealthEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityRegainHealthEvent(EntityEvent, Cancellable):
    """
    Stores data for health-regain events
    """

    def __init__(self, entity: "Entity", amount: float, regainReason: "RegainReason"):
        ...


    def getAmount(self) -> float:
        """
        Gets the amount of regained health

        Returns
        - The amount of health regained
        """
        ...


    def setAmount(self, amount: float) -> None:
        """
        Sets the amount of regained health

        Arguments
        - amount: the amount of health the entity will regain
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getRegainReason(self) -> "RegainReason":
        """
        Gets the reason for why the entity is regaining health

        Returns
        - A RegainReason detailing the reason for the entity regaining
            health
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class RegainReason(Enum):
        """
        An enum to specify the type of health regaining that is occurring
        """

        REGEN = 0
        """
        When a player regains health from regenerating due to Peaceful mode
        (difficulty=0)
        """
        SATIATED = 1
        """
        When a player regains health from regenerating due to their hunger
        being satisfied
        """
        EATING = 2
        """
        When a player regains health from eating consumables
        """
        ENDER_CRYSTAL = 3
        """
        When an ender dragon regains health from an ender crystal
        """
        MAGIC = 4
        """
        When a player is healed by a potion or spell
        """
        MAGIC_REGEN = 5
        """
        When a player is healed over time by a potion or spell
        """
        WITHER_SPAWN = 6
        """
        When a wither is filling its health during spawning
        """
        WITHER = 7
        """
        When an entity is damaged by the Wither potion effect
        """
        CUSTOM = 8
        """
        Any other reason not covered by the reasons above
        """



"""
Python module generated from Java source file org.bukkit.block.data.type.Snow

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Snow(BlockData):
    """
    'layers' represents the amount of layers of snow which are present in this
    block.
    
    May not be lower than .getMinimumLayers() or higher than
    .getMaximumLayers().
    """

    def getLayers(self) -> int:
        """
        Gets the value of the 'layers' property.

        Returns
        - the 'layers' value
        """
        ...


    def setLayers(self, layers: int) -> None:
        """
        Sets the value of the 'layers' property.

        Arguments
        - layers: the new 'layers' value
        """
        ...


    def getMinimumLayers(self) -> int:
        """
        Gets the minimum allowed value of the 'layers' property.

        Returns
        - the minimum 'layers' value
        """
        ...


    def getMaximumLayers(self) -> int:
        """
        Gets the maximum allowed value of the 'layers' property.

        Returns
        - the maximum 'layers' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.world.ChunkUnloadEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Chunk
from org.bukkit.event import HandlerList
from org.bukkit.event.world import *
from typing import Any, Callable, Iterable, Tuple


class ChunkUnloadEvent(ChunkEvent):
    """
    Called when a chunk is unloaded
    """

    def __init__(self, chunk: "Chunk"):
        ...


    def __init__(self, chunk: "Chunk", save: bool):
        ...


    def isSaveChunk(self) -> bool:
        """
        Return whether this chunk will be saved to disk.

        Returns
        - chunk save status
        """
        ...


    def setSaveChunk(self, saveChunk: bool) -> None:
        """
        Set whether this chunk will be saved to disk.

        Arguments
        - saveChunk: chunk save status
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingObject

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.io import Serializable
from typing import Any, Callable, Iterable, Tuple


class ForwardingObject:
    """
    An abstract base class for implementing the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>. The .delegate() method must be overridden to return the instance being decorated.
    
    This class does *not* forward the `hashCode` and `equals` methods through to
    the backing object, but relies on `Object`'s implementation. This is necessary to preserve
    the symmetry of `equals`. Custom definitions of equality are usually based on an interface,
    such as `Set` or `List`, so that the implementation of `equals` can cast the
    object being tested for equality to the custom interface. `ForwardingObject` implements no
    such custom interfaces directly; they are implemented only in subclasses. Therefore, forwarding
    `equals` would break symmetry, as the forwarding object might consider itself equal to the
    object being tested, but the reverse could not be True. This behavior is consistent with the
    JDK's collection wrappers, such as java.util.Collections.unmodifiableCollection. Use an
    interface-specific subclass of `ForwardingObject`, such as ForwardingList, to
    preserve equality behavior, or override `equals` directly.
    
    The `toString` method is forwarded to the delegate. Although this class does not
    implement Serializable, a serializable subclass may be created since this class has a
    parameter-less constructor.

    Author(s)
    - Mike Bostock

    Since
    - 2.0
    """

    def toString(self) -> str:
        """
        Returns the string representation generated by the delegate's `toString` method.
        """
        ...



"""
Python module generated from Java source file com.google.common.io.Closeables

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.io import *
from java.io import Closeable
from java.io import IOException
from java.io import InputStream
from java.io import Reader
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Closeables:
    """
    Utility methods for working with Closeable objects.

    Author(s)
    - Michael Lancaster

    Since
    - 1.0
    """

    @staticmethod
    def close(closeable: "Closeable", swallowIOException: bool) -> None:
        """
        Closes a Closeable, with control over whether an `IOException` may be thrown.
        This is primarily useful in a finally block, where a thrown exception needs to be logged but
        not propagated (otherwise the original exception will be lost).
        
        If `swallowIOException` is True then we never throw `IOException` but merely log
        it.
        
        Example:
        
        ````public void useStreamNicely() throws IOException {
          SomeStream stream = new SomeStream("foo");
          boolean threw = True;
          try {
            // ... code which does something with the stream ...
            threw = False;` finally {
            // If an exception occurs, rethrow it only if threw==False:
            Closeables.close(stream, threw);
          }
        }
        }```

        Arguments
        - closeable: the `Closeable` object to be closed, or null, in which case this method
            does nothing
        - swallowIOException: if True, don't propagate IO exceptions thrown by the `close`
            methods

        Raises
        - IOException: if `swallowIOException` is False and `close` throws an `IOException`.
        """
        ...


    @staticmethod
    def closeQuietly(inputStream: "InputStream") -> None:
        """
        Closes the given InputStream, logging any `IOException` that's thrown rather than
        propagating it.
        
        While it's not safe in the general case to ignore exceptions that are thrown when closing an
        I/O resource, it should generally be safe in the case of a resource that's being used only for
        reading, such as an `InputStream`. Unlike with writable resources, there's no chance that
        a failure that occurs when closing the stream indicates a meaningful problem such as a failure
        to flush all bytes to the underlying resource.

        Arguments
        - inputStream: the input stream to be closed, or `null` in which case this method
            does nothing

        Since
        - 17.0
        """
        ...


    @staticmethod
    def closeQuietly(reader: "Reader") -> None:
        """
        Closes the given Reader, logging any `IOException` that's thrown rather than
        propagating it.
        
        While it's not safe in the general case to ignore exceptions that are thrown when closing an
        I/O resource, it should generally be safe in the case of a resource that's being used only for
        reading, such as a `Reader`. Unlike with writable resources, there's no chance that a
        failure that occurs when closing the reader indicates a meaningful problem such as a failure to
        flush all bytes to the underlying resource.

        Arguments
        - reader: the reader to be closed, or `null` in which case this method does nothing

        Since
        - 17.0
        """
        ...



"""
Python module generated from Java source file org.bukkit.plugin.PluginAwareness

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class PluginAwareness:
    """
    Represents a concept that a plugin is aware of.
    
    The internal representation may be singleton, or be a parameterized
    instance, but must be immutable.
    """

    class Flags(Enum):
        """
        Each entry here represents a particular plugin's awareness. These can
        be checked by using PluginDescriptionFile.getAwareness().Set.contains(Object) contains(flag).
        """

        UTF8 = 0
        """
        This specifies that all (text) resources stored in a plugin's jar
        use UTF-8 encoding.

        Deprecated
        - all plugins are now assumed to be UTF-8 aware.
        """



"""
Python module generated from Java source file com.google.common.collect.Serialization

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from java.io import IOException
from java.io import ObjectInputStream
from java.io import ObjectOutputStream
from java.lang.reflect import Field
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Serialization:
    """
    Provides static methods for serializing collection classes.
    
    This class assists the implementation of collection classes. Do not use this class to
    serialize collections that are defined elsewhere.

    Author(s)
    - Jared Levy
    """





"""
Python module generated from Java source file com.google.common.collect.MapDifference

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import DoNotMock
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class MapDifference:
    """
    An object representing the differences between two maps.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    def areEqual(self) -> bool:
        """
        Returns `True` if there are no differences between the two maps; that is, if the maps are
        equal.
        """
        ...


    def entriesOnlyOnLeft(self) -> dict["K", "V"]:
        """
        Returns an unmodifiable map containing the entries from the left map whose keys are not present
        in the right map.
        """
        ...


    def entriesOnlyOnRight(self) -> dict["K", "V"]:
        """
        Returns an unmodifiable map containing the entries from the right map whose keys are not
        present in the left map.
        """
        ...


    def entriesInCommon(self) -> dict["K", "V"]:
        """
        Returns an unmodifiable map containing the entries that appear in both maps; that is, the
        intersection of the two maps.
        """
        ...


    def entriesDiffering(self) -> dict["K", "ValueDifference"["V"]]:
        """
        Returns an unmodifiable map describing keys that appear in both maps, but with different
        values.
        """
        ...


    def equals(self, object: "Object") -> bool:
        """
        Compares the specified object with this instance for equality. Returns `True` if the
        given object is also a `MapDifference` and the values returned by the .entriesOnlyOnLeft(), .entriesOnlyOnRight(), .entriesInCommon() and .entriesDiffering() of the two instances are equal.
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code for this instance. This is defined as the hash code of
        
        ````Arrays.asList(entriesOnlyOnLeft(), entriesOnlyOnRight(),
            entriesInCommon(), entriesDiffering())````
        """
        ...



"""
Python module generated from Java source file java.net.InetAddress

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import File
from java.io import IOException
from java.io import InvalidObjectException
from java.io import ObjectInputStream
from java.io.ObjectInputStream import GetField
from java.io import ObjectOutputStream
from java.io.ObjectOutputStream import PutField
from java.io import ObjectStreamException
from java.io import ObjectStreamField
from java.net import *
from java.util import Arrays
from java.util import NavigableSet
from java.util import Objects
from java.util import Scanner
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from java.util.concurrent import ConcurrentSkipListSet
from java.util.concurrent.atomic import AtomicLong
from jdk.internal.access import JavaNetInetAddressAccess
from jdk.internal.access import SharedSecrets
from sun.net import InetAddressCachePolicy
from sun.net.util import IPAddressUtil
from sun.nio.cs import UTF_8
from sun.security.action import *
from typing import Any, Callable, Iterable, Tuple


class InetAddress(Serializable):
    """
    This class represents an Internet Protocol (IP) address.
    
     An IP address is either a 32-bit or 128-bit unsigned number
    used by IP, a lower-level protocol on which protocols like UDP and
    TCP are built. The IP address architecture is defined by <a
    href="http://www.ietf.org/rfc/rfc790.txt">*RFC&nbsp;790:
    Assigned Numbers*</a>, <a
    href="http://www.ietf.org/rfc/rfc1918.txt"> *RFC&nbsp;1918:
    Address Allocation for Private Internets*</a>, <a
    href="http://www.ietf.org/rfc/rfc2365.txt">*RFC&nbsp;2365:
    Administratively Scoped IP Multicast*</a>, and <a
    href="http://www.ietf.org/rfc/rfc2373.txt">*RFC&nbsp;2373: IP
    Version 6 Addressing Architecture*</a>. An instance of an
    InetAddress consists of an IP address and possibly its
    corresponding host name (depending on whether it is constructed
    with a host name or whether it has already done reverse host name
    resolution).
    
    <h2> Address types </h2>
    
    <table class="striped" style="margin-left:2em">
      <caption style="display:none">Description of unicast and multicast address types</caption>
      <thead>
      <tr><th scope="col">Address Type</th><th scope="col">Description</th></tr>
      </thead>
      <tbody>
      <tr><th scope="row" style="vertical-align:top">unicast</th>
          <td>An identifier for a single interface. A packet sent to
            a unicast address is delivered to the interface identified by
            that address.
    
             The Unspecified Address -- Also called anylocal or wildcard
            address. It must never be assigned to any node. It indicates the
            absence of an address. One example of its use is as the target of
            bind, which allows a server to accept a client connection on any
            interface, in case the server host has multiple interfaces.
    
             The *unspecified* address must not be used as
            the destination address of an IP packet.
    
             The *Loopback* Addresses -- This is the address
            assigned to the loopback interface. Anything sent to this
            IP address loops around and becomes IP input on the local
            host. This address is often used when testing a
            client.</td></tr>
      <tr><th scope="row" style="vertical-align:top">multicast</th>
          <td>An identifier for a set of interfaces (typically belonging
            to different nodes). A packet sent to a multicast address is
            delivered to all interfaces identified by that address.</td></tr>
    </tbody>
    </table>
    
    <h3> IP address scope </h3>
    
     *Link-local* addresses are designed to be used for addressing
    on a single link for purposes such as auto-address configuration,
    neighbor discovery, or when no routers are present.
    
     *Site-local* addresses are designed to be used for addressing
    inside of a site without the need for a global prefix.
    
     *Global* addresses are unique across the internet.
    
    <h3> Textual representation of IP addresses </h3>
    
    The textual representation of an IP address is address family specific.
    
    
    
    For IPv4 address format, please refer to <A
    HREF="Inet4Address.html#format">Inet4Address#format</A>; For IPv6
    address format, please refer to <A
    HREF="Inet6Address.html#format">Inet6Address#format</A>.
    
    <P>There is a <a href="doc-files/net-properties.html#Ipv4IPv6">couple of
    System Properties</a> affecting how IPv4 and IPv6 addresses are used.</P>
    
    <h3> Host Name Resolution </h3>
    
    Host name-to-IP address *resolution* is accomplished through
    the use of a combination of local machine configuration information
    and network naming services such as the Domain Name System (DNS)
    and Network Information Service(NIS). The particular naming
    services(s) being used is by default the local machine configured
    one. For any host name, its corresponding IP address is returned.
    
     *Reverse name resolution* means that for any IP address,
    the host associated with the IP address is returned.
    
     The InetAddress class provides methods to resolve host names to
    their IP addresses and vice versa.
    
    <h3> InetAddress Caching </h3>
    
    The InetAddress class has a cache to store successful as well as
    unsuccessful host name resolutions.
    
     By default, when a security manager is installed, in order to
    protect against DNS spoofing attacks,
    the result of positive host name resolutions are
    cached forever. When a security manager is not installed, the default
    behavior is to cache entries for a finite (implementation dependent)
    period of time. The result of unsuccessful host
    name resolution is cached for a very short period of time (10
    seconds) to improve performance.
    
     If the default behavior is not desired, then a Java security property
    can be set to a different Time-to-live (TTL) value for positive
    caching. Likewise, a system admin can configure a different
    negative caching TTL value when needed.
    
     Two Java security properties control the TTL values used for
     positive and negative host name resolution caching:
    
    <dl style="margin-left:2em">
    <dt>**networkaddress.cache.ttl**</dt>
    <dd>Indicates the caching policy for successful name lookups from
    the name service. The value is specified as an integer to indicate
    the number of seconds to cache the successful lookup. The default
    setting is to cache for an implementation specific period of time.
    
    A value of -1 indicates "cache forever".
    </dd>
    <dt>**networkaddress.cache.negative.ttl** (default: 10)</dt>
    <dd>Indicates the caching policy for un-successful name lookups
    from the name service. The value is specified as an integer to
    indicate the number of seconds to cache the failure for
    un-successful lookups.
    
    A value of 0 indicates "never cache".
    A value of -1 indicates "cache forever".
    </dd>
    </dl>

    Author(s)
    - Chris Warth

    See
    - java.net.InetAddress.getLocalHost()

    Since
    - 1.0
    """

    def isMulticastAddress(self) -> bool:
        """
        Utility routine to check if the InetAddress is an
        IP multicast address.

        Returns
        - a `boolean` indicating if the InetAddress is
        an IP multicast address

        Since
        - 1.1
        """
        ...


    def isAnyLocalAddress(self) -> bool:
        """
        Utility routine to check if the InetAddress is a wildcard address.

        Returns
        - a `boolean` indicating if the InetAddress is
                a wildcard address.

        Since
        - 1.4
        """
        ...


    def isLoopbackAddress(self) -> bool:
        """
        Utility routine to check if the InetAddress is a loopback address.

        Returns
        - a `boolean` indicating if the InetAddress is
        a loopback address; or False otherwise.

        Since
        - 1.4
        """
        ...


    def isLinkLocalAddress(self) -> bool:
        """
        Utility routine to check if the InetAddress is an link local address.

        Returns
        - a `boolean` indicating if the InetAddress is
        a link local address; or False if address is not a link local unicast address.

        Since
        - 1.4
        """
        ...


    def isSiteLocalAddress(self) -> bool:
        """
        Utility routine to check if the InetAddress is a site local address.

        Returns
        - a `boolean` indicating if the InetAddress is
        a site local address; or False if address is not a site local unicast address.

        Since
        - 1.4
        """
        ...


    def isMCGlobal(self) -> bool:
        """
        Utility routine to check if the multicast address has global scope.

        Returns
        - a `boolean` indicating if the address has
                is a multicast address of global scope, False if it is not
                of global scope or it is not a multicast address

        Since
        - 1.4
        """
        ...


    def isMCNodeLocal(self) -> bool:
        """
        Utility routine to check if the multicast address has node scope.

        Returns
        - a `boolean` indicating if the address has
                is a multicast address of node-local scope, False if it is not
                of node-local scope or it is not a multicast address

        Since
        - 1.4
        """
        ...


    def isMCLinkLocal(self) -> bool:
        """
        Utility routine to check if the multicast address has link scope.

        Returns
        - a `boolean` indicating if the address has
                is a multicast address of link-local scope, False if it is not
                of link-local scope or it is not a multicast address

        Since
        - 1.4
        """
        ...


    def isMCSiteLocal(self) -> bool:
        """
        Utility routine to check if the multicast address has site scope.

        Returns
        - a `boolean` indicating if the address has
                is a multicast address of site-local scope, False if it is not
                of site-local scope or it is not a multicast address

        Since
        - 1.4
        """
        ...


    def isMCOrgLocal(self) -> bool:
        """
        Utility routine to check if the multicast address has organization scope.

        Returns
        - a `boolean` indicating if the address has
                is a multicast address of organization-local scope,
                False if it is not of organization-local scope
                or it is not a multicast address

        Since
        - 1.4
        """
        ...


    def isReachable(self, timeout: int) -> bool:
        """
        Test whether that address is reachable. Best effort is made by the
        implementation to try to reach the host, but firewalls and server
        configuration may block requests resulting in a unreachable status
        while some specific ports may be accessible.
        A typical implementation will use ICMP ECHO REQUESTs if the
        privilege can be obtained, otherwise it will try to establish
        a TCP connection on port 7 (Echo) of the destination host.
        
        The timeout value, in milliseconds, indicates the maximum amount of time
        the try should take. If the operation times out before getting an
        answer, the host is deemed unreachable. A negative value will result
        in an IllegalArgumentException being thrown.

        Arguments
        - timeout: the time, in milliseconds, before the call aborts

        Returns
        - a `boolean` indicating if the address is reachable.

        Raises
        - IOException: if a network error occurs
        - IllegalArgumentException: if `timeout` is negative.

        Since
        - 1.5
        """
        ...


    def isReachable(self, netif: "NetworkInterface", ttl: int, timeout: int) -> bool:
        """
        Test whether that address is reachable. Best effort is made by the
        implementation to try to reach the host, but firewalls and server
        configuration may block requests resulting in a unreachable status
        while some specific ports may be accessible.
        A typical implementation will use ICMP ECHO REQUESTs if the
        privilege can be obtained, otherwise it will try to establish
        a TCP connection on port 7 (Echo) of the destination host.
        
        The `network interface` and `ttl` parameters
        let the caller specify which network interface the test will go through
        and the maximum number of hops the packets should go through.
        A negative value for the `ttl` will result in an
        IllegalArgumentException being thrown.
        
        The timeout value, in milliseconds, indicates the maximum amount of time
        the try should take. If the operation times out before getting an
        answer, the host is deemed unreachable. A negative value will result
        in an IllegalArgumentException being thrown.

        Arguments
        - netif: the NetworkInterface through which the
                           test will be done, or null for any interface
        - ttl: the maximum numbers of hops to try or 0 for the
                         default
        - timeout: the time, in milliseconds, before the call aborts

        Returns
        - a `boolean` indicating if the address is reachable.

        Raises
        - IllegalArgumentException: if either `timeout`
                                 or `ttl` are negative.
        - IOException: if a network error occurs

        Since
        - 1.5
        """
        ...


    def getHostName(self) -> str:
        """
        Gets the host name for this IP address.
        
        If this InetAddress was created with a host name,
        this host name will be remembered and returned;
        otherwise, a reverse name lookup will be performed
        and the result will be returned based on the system
        configured name lookup service. If a lookup of the name service
        is required, call
        .getCanonicalHostName() getCanonicalHostName.
        
        If there is a security manager, its
        `checkConnect` method is first called
        with the hostname and `-1`
        as its arguments to see if the operation is allowed.
        If the operation is not allowed, it will return
        the textual representation of the IP address.

        Returns
        - the host name for this IP address, or if the operation
           is not allowed by the security check, the textual
           representation of the IP address.

        See
        - SecurityManager.checkConnect
        """
        ...


    def getCanonicalHostName(self) -> str:
        """
        Gets the fully qualified domain name for this IP address.
        Best effort method, meaning we may not be able to return
        the FQDN depending on the underlying system configuration.
        
        If there is a security manager, this method first
        calls its `checkConnect` method
        with the hostname and `-1`
        as its arguments to see if the calling code is allowed to know
        the hostname for this IP address, i.e., to connect to the host.
        If the operation is not allowed, it will return
        the textual representation of the IP address.

        Returns
        - the fully qualified domain name for this IP address,
           or if the operation is not allowed by the security check,
           the textual representation of the IP address.

        See
        - SecurityManager.checkConnect

        Since
        - 1.4
        """
        ...


    def getAddress(self) -> list[int]:
        """
        Returns the raw IP address of this `InetAddress`
        object. The result is in network byte order: the highest order
        byte of the address is in `getAddress()[0]`.

        Returns
        - the raw IP address of this object.
        """
        ...


    def getHostAddress(self) -> str:
        """
        Returns the IP address string in textual presentation.

        Returns
        - the raw IP address in a string format.

        Since
        - 1.0.2
        """
        ...


    def hashCode(self) -> int:
        """
        Returns a hashcode for this IP address.

        Returns
        - a hash code value for this IP address.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Compares this object against the specified object.
        The result is `True` if and only if the argument is
        not `null` and it represents the same IP address as
        this object.
        
        Two instances of `InetAddress` represent the same IP
        address if the length of the byte arrays returned by
        `getAddress` is the same for both, and each of the
        array components is the same for the byte arrays.

        Arguments
        - obj: the object to compare against.

        Returns
        - `True` if the objects are the same;
                 `False` otherwise.

        See
        - java.net.InetAddress.getAddress()
        """
        ...


    def toString(self) -> str:
        """
        Converts this IP address to a `String`. The
        string returned is of the form: hostname / literal IP
        address.
        
        If the host name is unresolved, no reverse name service lookup
        is performed. The hostname part will be represented by an empty string.

        Returns
        - a string representation of this IP address.
        """
        ...


    @staticmethod
    def getByAddress(host: str, addr: list[int]) -> "InetAddress":
        """
        Creates an InetAddress based on the provided host name and IP address.
        No name service is checked for the validity of the address.
        
         The host name can either be a machine name, such as
        "`www.example.com`", or a textual representation of its IP
        address.
         No validity checking is done on the host name either.
        
         If addr specifies an IPv4 address an instance of Inet4Address
        will be returned; otherwise, an instance of Inet6Address
        will be returned.
        
         IPv4 address byte array must be 4 bytes long and IPv6 byte array
        must be 16 bytes long

        Arguments
        - host: the specified host
        - addr: the raw IP address in network byte order

        Returns
        - an InetAddress object created from the raw IP address.

        Raises
        - UnknownHostException: if IP address is of illegal length

        Since
        - 1.4
        """
        ...


    @staticmethod
    def getByName(host: str) -> "InetAddress":
        """
        Determines the IP address of a host, given the host's name.
        
         The host name can either be a machine name, such as
        "`www.example.com`", or a textual representation of its
        IP address. If a literal IP address is supplied, only the
        validity of the address format is checked.
        
         For `host` specified in literal IPv6 address,
        either the form defined in RFC 2732 or the literal IPv6 address
        format defined in RFC 2373 is accepted. IPv6 scoped addresses are also
        supported. See <a href="Inet6Address.html#scoped">here</a> for a description of IPv6
        scoped addresses.
        
         If the host is `null` or `host.length()` is equal
        to zero, then an `InetAddress` representing an address of the
        loopback interface is returned.
        See <a href="http://www.ietf.org/rfc/rfc3330.txt">RFC&nbsp;3330</a>
        section&nbsp;2 and <a href="http://www.ietf.org/rfc/rfc2373.txt">RFC&nbsp;2373</a>
        section&nbsp;2.5.3.
        
         If there is a security manager, and `host` is not `null`
        or `host.length()` is not equal to zero, the security manager's
        `checkConnect` method is called with the hostname and `-1`
        as its arguments to determine if the operation is allowed.

        Arguments
        - host: the specified host, or `null`.

        Returns
        - an IP address for the given host name.

        Raises
        - UnknownHostException: if no IP address for the
                      `host` could be found, or if a scope_id was specified
                      for a global IPv6 address.
        - SecurityException: if a security manager exists
                    and its checkConnect method doesn't allow the operation
        """
        ...


    @staticmethod
    def getAllByName(host: str) -> list["InetAddress"]:
        """
        Given the name of a host, returns an array of its IP addresses,
        based on the configured name service on the system.
        
         The host name can either be a machine name, such as
        "`www.example.com`", or a textual representation of its IP
        address. If a literal IP address is supplied, only the
        validity of the address format is checked.
        
         For `host` specified in *literal IPv6 address*,
        either the form defined in RFC 2732 or the literal IPv6 address
        format defined in RFC 2373 is accepted. A literal IPv6 address may
        also be qualified by appending a scoped zone identifier or scope_id.
        The syntax and usage of scope_ids is described
        <a href="Inet6Address.html#scoped">here</a>.
        
         If the host is `null` or `host.length()` is equal
        to zero, then an `InetAddress` representing an address of the
        loopback interface is returned.
        See <a href="http://www.ietf.org/rfc/rfc3330.txt">RFC&nbsp;3330</a>
        section&nbsp;2 and <a href="http://www.ietf.org/rfc/rfc2373.txt">RFC&nbsp;2373</a>
        section&nbsp;2.5.3. 
        
         If there is a security manager, and `host` is not `null`
        or `host.length()` is not equal to zero, the security manager's
        `checkConnect` method is called with the hostname and `-1`
        as its arguments to determine if the operation is allowed.

        Arguments
        - host: the name of the host, or `null`.

        Returns
        - an array of all the IP addresses for a given host name.

        Raises
        - UnknownHostException: if no IP address for the
                      `host` could be found, or if a scope_id was specified
                      for a global IPv6 address.
        - SecurityException: if a security manager exists and its
                      `checkConnect` method doesn't allow the operation.

        See
        - SecurityManager.checkConnect
        """
        ...


    @staticmethod
    def getLoopbackAddress() -> "InetAddress":
        """
        Returns the loopback address.
        
        The InetAddress returned will represent the IPv4
        loopback address, 127.0.0.1, or the IPv6 loopback
        address, ::1. The IPv4 loopback address returned
        is only one of many in the form 127.*.*.*

        Returns
        - the InetAddress loopback instance.

        Since
        - 1.7
        """
        ...


    @staticmethod
    def getByAddress(addr: list[int]) -> "InetAddress":
        """
        Returns an `InetAddress` object given the raw IP address .
        The argument is in network byte order: the highest order
        byte of the address is in `getAddress()[0]`.
        
         This method doesn't block, i.e. no reverse name service lookup
        is performed.
        
         IPv4 address byte array must be 4 bytes long and IPv6 byte array
        must be 16 bytes long

        Arguments
        - addr: the raw IP address in network byte order

        Returns
        - an InetAddress object created from the raw IP address.

        Raises
        - UnknownHostException: if IP address is of illegal length

        Since
        - 1.4
        """
        ...


    @staticmethod
    def getLocalHost() -> "InetAddress":
        """
        Returns the address of the local host. This is achieved by retrieving
        the name of the host from the system, then resolving that name into
        an `InetAddress`.
        
        <P>Note: The resolved address may be cached for a short period of time.
        </P>
        
        If there is a security manager, its
        `checkConnect` method is called
        with the local host name and `-1`
        as its arguments to see if the operation is allowed.
        If the operation is not allowed, an InetAddress representing
        the loopback address is returned.

        Returns
        - the address of the local host.

        Raises
        - UnknownHostException: if the local host name could not
                    be resolved into an address.

        See
        - java.net.InetAddress.getByName(java.lang.String)
        """
        ...
